@@ -2,34 +2,34 @@
 /*******************************************************************************
  * Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
  *
- * This file is part of XTPcpp.
+ * This file is part of i2MassChroQ.
  *
- *     XTPcpp is free software: you can redistribute it and/or modify
+ *     i2MassChroQ is free software: you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation, either version 3 of the License, or
  *     (at your option) any later version.
  *
- *     XTPcpp is distributed in the hope that it will be useful,
+ *     i2MassChroQ is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
  *
  *     You should have received a copy of the GNU General Public License
- *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
+ *     along with i2MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
  *
  ******************************************************************************/
 
 #include "projectwindow.h"
 #include "ui_project_view.h"
 #include "../mainwindow.h"
-#include "gui/peptide_list_view/peptidelistwindow.h"
-#include "gui/protein_list_view/proteinlistwindow.h"
+#include "gui/lists/peptide_list_view/peptidelistwindow.h"
+#include "gui/lists/protein_list_view/proteinlistwindow.h"
 #include "gui/project_view/identification_group_widget/identificationgroupwidget.h"
 #include <QDebug>
 #include <QApplication>
 #include <QGridLayout>
 #include <QMessageBox>
-#include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/core/pappsoexception.h>
 #include <numeric>
 #include "../workerthread.h"
 #include "../../core/labeling/labelingmethod.h"
@@ -112,6 +112,10 @@ ProjectWindow::ProjectWindow(MainWindow *parent)
           mp_mainWindow,
           &MainWindow::doActionMassChroQ);
 
+  connect(mp_mainWindow->getWorkerThread(),
+          &WorkerThread::tiddResultText,
+          this,
+          &ProjectWindow::receiveTiddResults);
   //
   // grouping
   /*
@@ -312,15 +316,22 @@ ProjectWindow::computeFdr()
       for(IdentificationGroup *identification_group :
           msp_project.get()->getIdentificationGroupList())
         {
+          qDebug() << identification_group;
           total_prot += identification_group->countProteinMatch(state);
+          qDebug() << "total_prot=" << total_prot;
           false_prot += identification_group->countDecoyProteinMatch(state);
+          qDebug();
           total_psm += identification_group->countPeptideEvidence(state);
+          qDebug() << "count pe";
           false_psm += identification_group->countDecoyPeptideEvidence(state);
+          qDebug();
 
           total_peptide += identification_group->countPeptideMassSample(state);
+          qDebug();
           false_peptide +=
             identification_group->countDecoyPeptideMassSample(state);
         }
+      qDebug();
       ui->protein_fdr_label->setText(QString("%1 %").arg(QString::number(
         (Utils::computeFdr(false_prot, total_prot - false_prot)) * 100.0,
         'f',
@@ -334,6 +345,7 @@ ProjectWindow::computeFdr()
         (Utils::computeFdr(false_psm, total_psm - false_psm)) * 100.0,
         'f',
         4)));
+      qDebug();
     }
   catch(pappso::PappsoException &exception_pappso)
     {
@@ -356,10 +368,10 @@ ProjectWindow::computeMassPrecision()
     {
       ValidationState state = ValidationState::validAndChecked;
       std::vector<pappso::pappso_double> delta_list;
-      pappso::PrecisionUnit unit = pappso::PrecisionUnit::dalton;
+      pappso::Enums::PrecisionUnit unit = pappso::Enums::PrecisionUnit::dalton;
       if(ui->precision_unit_combobox->currentText() == "ppm")
         {
-          unit = pappso::PrecisionUnit::ppm;
+          unit = pappso::Enums::PrecisionUnit::ppm;
         }
 
       for(IdentificationGroup *identification_group :
@@ -368,6 +380,7 @@ ProjectWindow::computeMassPrecision()
           identification_group->collectMhDelta(delta_list, unit, state);
         }
 
+      std::sort(delta_list.begin(), delta_list.end());
 
       qDebug() << " accumulate";
       pappso::pappso_double sum =
@@ -386,7 +399,6 @@ ProjectWindow::computeMassPrecision()
             "filter parameters (decoy regexp or database particularly)"));
         }
 
-      std::sort(delta_list.begin(), delta_list.end());
       pappso::pappso_double median = delta_list[(delta_list.size() / 2)];
 
 
@@ -467,8 +479,7 @@ ProjectWindow::doDecoySelectionChanged()
 }
 
 void
-ProjectWindow::doAutomaticFilterParametersChanged(
-  AutomaticFilterParameters parameters [[maybe_unused]])
+ProjectWindow::doAutomaticFilterParametersChanged()
 {
   qDebug() << " begin ";
   ui->apply_filter_button->setEnabled(true);
@@ -508,6 +519,14 @@ ProjectWindow::doDisplayLoadingPercent(int value)
   _p_waiting_message_dialog->percent(value);
 }
 
+void
+ProjectWindow::doDisplaySubTaskPercent(int value)
+{
+  qDebug() << value;
+  _p_waiting_message_dialog->subTaskPercent(value);
+}
+
+
 void
 ProjectWindow::doGroupingFinished()
 {
@@ -574,7 +593,7 @@ void
 ProjectWindow::doViewPeptideDetail(PeptideEvidence *peptide_evidence)
 {
 
-  qDebug() << "ProjectWindow::doViewPeptideDetail begin " << peptide_evidence;
+  qDebug() << " begin " << peptide_evidence;
   if(_peptide_detail_window_collection.size() == 0)
     {
       connectNewPeptideDetailWindow();
@@ -592,7 +611,7 @@ ProjectWindow::doViewPeptideDetail(PeptideEvidence *peptide_evidence)
   //_p_current_peptide_detail_window->activateWindow();
 
   emit peptideEvidenceSelected(peptide_evidence);
-  qDebug() << "ProjectWindow::doViewPeptideDetail end";
+  qDebug() << " end";
 }
 
 void
@@ -600,7 +619,7 @@ ProjectWindow::doViewProteinDetail(ProteinMatch *protein_match)
 {
 
 
-  qDebug() << "ProjectWindow::doViewProteinDetail begin";
+  qDebug() << " begin";
   if(_protein_detail_window_collection.size() == 0)
     {
       connectNewProteinDetailWindow();
@@ -616,7 +635,7 @@ ProjectWindow::doViewProteinDetail(ProteinMatch *protein_match)
   _p_current_protein_detail_window->show();
   //_p_current_protein_detail_window->raise();
   //_p_current_protein_detail_window->activateWindow();
-  qDebug() << "ProjectWindow::doViewProteinDetail end";
+  qDebug() << " end";
 }
 
 void
@@ -686,7 +705,10 @@ ProjectWindow::doViewPtmIslandList(IdentificationGroup *p_identification_group)
   _p_current_ptm_island_list_window->setIdentificationGroup(
     p_identification_group);
 
-  doPtmIslandGrouping(p_identification_group);
+  for(auto &id_group : msp_project.get()->getIdentificationGroupList())
+    {
+      doPtmIslandGrouping(id_group);
+    }
   // emit identificationGroupGrouped(p_identification_group);
   qDebug() << " end";
 }
@@ -813,7 +835,7 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
     msp_project.get()->getIdentificationGroupList();
 
 
-  doViewProteinList(identification_list[0]);
+  // doViewProteinList(identification_list[0]);
 
   // qDeleteAll(ui->identifications_widget->children());
   QLayoutItem *wItem;
@@ -894,7 +916,7 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
                                            .getIdentificationDataSourceList())
     {
       if(identification_date_source.get()->getIdentificationEngine() ==
-         IdentificationEngine::DeepProt)
+         IdentificationEngine::SpecOMS)
         {
           hasDeepProt = true;
           break;
@@ -925,6 +947,8 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
           mpa_deepProtGui = nullptr;
         }
     }
+
+  ui->project_name_line_edit->setText(msp_project.get()->getProjectName());
   qDebug();
   // doAutomaticFilterParametersChanged(params);
   // doFdrChanged();
@@ -1010,10 +1034,11 @@ ProjectWindow::doIdentificationGroupEdited(
 }
 
 void
-ProjectWindow::viewError(QString error)
+ProjectWindow::viewError(const QString &error)
 {
-  QMessageBox::warning(
-    this, tr("Oops! an error occurred in XTPCPP. Don't panic :"), error);
+  qWarning() << "ProjectWindow::viewError" << error;
+  // QMessageBox::warning(
+  //  this, tr("Oops! an error occurred in i2MassChroQ. Don't panic :"), error);
 }
 
 
@@ -1128,6 +1153,35 @@ ProjectWindow::doComputePsmQvalues()
     }
 }
 
+void
+ProjectWindow::doComputeTidd()
+{
+  try
+    {
+      showWaitingMessage(tr("Computing TIDD svm probabilities"));
+
+      TiddParameters params;
+
+      params.m_ms2precision = ui->precision_widget->getPrecision();
+      params.m_iteration    = ui->max_iteration_spinbox->value();
+      params.m_trainSize    = ui->max_train_size_spinbox->value();
+
+      emit operateTiddComputing(msp_project, params);
+    }
+  catch(pappso::PappsoException &exception_pappso)
+    {
+      hideWaitingMessage();
+      QMessageBox::warning(
+        this, tr("Error filtering results :"), exception_pappso.qwhat());
+    }
+  catch(std::exception &exception_std)
+    {
+      hideWaitingMessage();
+      QMessageBox::warning(
+        this, tr("Error filtering results :"), exception_std.what());
+    }
+}
+
 void
 ProjectWindow::doApplyFilter()
 {
@@ -1245,3 +1299,23 @@ ProjectWindow::doShowStopButton()
   qDebug();
   _p_waiting_message_dialog->showStopButton();
 }
+
+void
+ProjectWindow::receiveTiddResults(TiddResults message)
+{
+  ui->tidd_results_text_label->setText(
+    tr("SVM probability threshold for %1 FDR is %2")
+      .arg(QString::number(message.fdr * 100.0, 'f', 4))
+      .arg(message.svmProbThreshold));
+
+  AutomaticFilterParameters params =
+    ui->filter_parameter_widget->getAutomaticFilterParameters();
+  params.setSvmprobThreshold(message.svmProbThreshold);
+  ui->filter_parameter_widget->setAutomaticFilterParameters(params);
+}
+
+const QString
+ProjectWindow::getProjectName() const
+{
+  return ui->project_name_line_edit->text();
+}
