@@ -8,20 +8,20 @@
 /*******************************************************************************
  * Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
  *
- * This file is part of XTPcpp.
+ * This file is part of i2MassChroQ.
  *
- *     XTPcpp is free software: you can redistribute it and/or modify
+ *     i2MassChroQ is free software: you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
  *     the Free Software Foundation, either version 3 of the License, or
  *     (at your option) any later version.
  *
- *     XTPcpp is distributed in the hope that it will be useful,
+ *     i2MassChroQ is distributed in the hope that it will be useful,
  *     but WITHOUT ANY WARRANTY; without even the implied warranty of
  *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *     GNU General Public License for more details.
  *
  *     You should have received a copy of the GNU General Public License
- *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
+ *     along with i2MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
  *
  * Contributors:
  *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
@@ -37,7 +37,7 @@
 #include <QMessageBox>
 #include <QStandardPaths>
 #include <QDesktopServices>
-#include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/core/pappsoexception.h>
 #include "../../files/tandemparametersfile.h"
 #include "../../utils/utils.h"
 
@@ -109,7 +109,9 @@ TandemRunDialog::setPresetName(QString preset_name)
         ui->preset_combobox->itemData(ui->preset_combobox->currentIndex())
           .value<QString>());
 
-      if(param_file.isTandemPresetFile())
+      param_file.getTandemParameters();
+      if((param_file.getTandemFileType() == ParamFileType::preset) ||
+         (param_file.getTandemFileType() == ParamFileType::result))
         {
           QSettings settings;
           settings.setValue("tandem/preset_name", preset_name);
@@ -128,7 +130,8 @@ TandemRunDialog::setPresetName(QString preset_name)
                 {
 
                   QMessageBox::warning(
-                    this, tr("Error reading X!Tandem parameter file"),
+                    this,
+                    tr("Error reading X!Tandem parameter file"),
                     tr("Error reading parameter file \"%1\":\n%2")
                       .arg(param_file.getAbsoluteFilePath())
                       .arg(error.qwhat()));
@@ -161,7 +164,10 @@ TandemRunDialog::fillPresetComboBox()
   for(QFileInfo file_info : preset_dir.entryInfoList())
     {
       TandemParametersFile param_file(file_info.absoluteFilePath());
-      if(param_file.isTandemPresetFile())
+
+      param_file.getTandemParameters();
+      if((param_file.getTandemFileType() == ParamFileType::preset) ||
+         (param_file.getTandemFileType() == ParamFileType::result))
         {
           ui->preset_combobox->addItem(file_info.baseName(),
                                        QVariant(file_info.absoluteFilePath()));
@@ -176,7 +182,7 @@ TandemRunDialog::fillPresetComboBox()
 void
 TandemRunDialog::reset()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   QSettings settings;
   QString default_output_location =
     settings.value("path/identificationfiles", "").toString();
@@ -192,7 +198,7 @@ TandemRunDialog::reset()
       settings.setValue("path/identificationfiles",
   QFileInfo(filenames[0]).absolutePath());
   }*/
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
@@ -241,9 +247,13 @@ TandemRunDialog::editPresets()
 
 #if QT_VERSION >= 0x050000
   // Qt5 code
-  connect(_p_preset_dialog, &EditTandemPresetDialog::accepted, this,
+  connect(_p_preset_dialog,
+          &EditTandemPresetDialog::accepted,
+          this,
           &TandemRunDialog::acceptPresetEdit);
-  connect(_p_preset_dialog, &EditTandemPresetDialog::rejected, this,
+  connect(_p_preset_dialog,
+          &EditTandemPresetDialog::rejected,
+          this,
           &TandemRunDialog::rejectPresetEdit);
 #else
   // Qt4 code
@@ -310,7 +320,9 @@ TandemRunDialog::selectFastaFiles()
         settings.value("path/tandemrun_fastafiles_directory", "").toString();
 
       QStringList filenames = QFileDialog::getOpenFileNames(
-        this, tr("FASTA files"), default_fasta_location,
+        this,
+        tr("FASTA files"),
+        default_fasta_location,
         tr("FASTA files (*.fasta);;all files (*)"));
 
       if(filenames.size() > 0)
@@ -341,7 +353,8 @@ TandemRunDialog::selectXtandemExe()
 
 
       QString filename =
-        QFileDialog::getOpenFileName(this, tr("select X!Tandem executable"),
+        QFileDialog::getOpenFileName(this,
+                                     tr("select X!Tandem executable"),
                                      QDir(tandem_bin_path).absolutePath(),
                                      tr("all files (*);;exe files (*.exe)"));
       fillTandemBinPath(filename, true);
@@ -364,7 +377,9 @@ TandemRunDialog::selectMzFiles()
         settings.value("path/tandemrun_mzfiles_directory", "").toString();
 
       QStringList filenames = QFileDialog::getOpenFileNames(
-        this, tr("select peak list files"), default_mz_location,
+        this,
+        tr("select peak list files"),
+        default_mz_location,
         tr("any mz files (*.mzXML *.mzxml *.mzML *.mzml *.mgf *.tdf);;mzXML "
            "(*.mzXML "
            "*.mzxml);;mzML (*.mzML *.mzml);;MGF (*.mgf);; tdf (*.tdf);;all "
@@ -398,7 +413,7 @@ TandemRunDialog::selectTdfFolder()
         settings.value("path/tandemrun_tdf_directory", "/").toString();
       QFileDialog directories_dialog;
       directories_dialog.setDirectory(default_tdf_location);
-      directories_dialog.setFileMode(QFileDialog::DirectoryOnly);
+      directories_dialog.setFileMode(QFileDialog::Directory);
       directories_dialog.setOption(QFileDialog::DontUseNativeDialog, true);
       directories_dialog.setWindowTitle("Select the timsTOF folders");
       QListView *lView = directories_dialog.findChild<QListView *>("listView");
@@ -450,7 +465,7 @@ TandemRunDialog::selectTdfFolder()
               for(QFileInfo file : files)
                 {
                   if(Utils::guessDataFileFormatFromFile(
-                       file.absoluteFilePath()) == pappso::MzFormat::MGF)
+                       file.absoluteFilePath()) == pappso::Enums::MsDataFormat::MGF)
                     {
                       results.append(file.absoluteFilePath());
                     }
@@ -581,14 +596,23 @@ void
 TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
                                    bool popup_firefox)
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-           << tandem_bin_path_in;
+  qDebug() << tandem_bin_path_in;
   QSettings settings;
   if(tandem_bin_path_in.isEmpty())
     {
       // try to find default X!Tandem, depending on platform
       ui->tandem_bin_label->setText("");
-      if(QFileInfo("/usr/bin/tandem").exists())
+
+      QFileInfo file(QCoreApplication::applicationDirPath() + "/tandemng.exe");
+      if(file.exists())
+        { // for Windows
+          fillTandemBinPath(file.absoluteFilePath(), false);
+        }
+      else if(QFileInfo("/usr/bin/tandemng").exists())
+        {
+          fillTandemBinPath("/usr/bin/tandemng", false);
+        }
+      else if(QFileInfo("/usr/bin/tandem").exists())
         {
           fillTandemBinPath("/usr/bin/tandem", false);
         }
@@ -646,11 +670,12 @@ TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
               QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
             }
           QMessageBox::warning(
-            this, tr("Wrong tandem.exe file"),
+            this,
+            tr("Wrong tandem.exe file"),
             tr("%1 is not executable.").arg(tandem_bin_path));
         }
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 
@@ -668,7 +693,8 @@ TandemRunDialog::checkXtandemBin()
   if((tandem_bin_path.isEmpty()) || (tandem_bin.baseName() == "i2masschroq"))
     {
       QMessageBox::warning(
-        this, tr("Wrong X!Tandem configuration"),
+        this,
+        tr("Wrong X!Tandem configuration"),
         tr("X!Tandem .exe file is not set.\n%1").arg(tandem_install_text));
 
       QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
@@ -688,7 +714,8 @@ TandemRunDialog::checkXtandemBin()
           catch(pappso::PappsoException &error)
             {
               QMessageBox::warning(
-                this, tr("Wrong X!Tandem exe file"),
+                this,
+                tr("Wrong X!Tandem exe file"),
                 tr("%1 does not seem to be a valid X!Tandem version.\n%2")
                   .arg(tandem_bin.absoluteFilePath())
                   .arg(tandem_install_text));
@@ -698,7 +725,8 @@ TandemRunDialog::checkXtandemBin()
         }
       else
         {
-          QMessageBox::warning(this, tr("Wrong X!Tandem exe file"),
+          QMessageBox::warning(this,
+                               tr("Wrong X!Tandem exe file"),
                                tr("%1 is not executable.\n%2")
                                  .arg(tandem_bin_path)
                                  .arg(tandem_install_text));
